/*
 * Copyright 2012 Martin Skurla
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package org.crazyjavahacking.astvisualizer.util;


import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.Reader;

import org.crazyjavahacking.astvisualizer.impl.javac.util.FileUtils;
import org.crazyjavahacking.astvisualizer.impl.javac.util.JavaCompilerUtils;

import com.sun.source.tree.CompilationUnitTree;


/**
 * Compilation utility class.
 *
 * @author Martin
 *
 * @since 1.0.3
 */
public class CompilationUtils {

    //-----------------------------------------------------------------------------------------------------------------
    // Constructors.
    //-----------------------------------------------------------------------------------------------------------------
    private CompilationUtils() {}


    //-----------------------------------------------------------------------------------------------------------------
    // Public Methods.
    //-----------------------------------------------------------------------------------------------------------------
    /**
     * Returns source code after compilation.
     *
     * @param javaSourceFile Java source file
     *
     * @return source code after compilation
     *
     * @throws FileNotFoundException if given file does not exist
     */
    public static String sourceCodeAfterCompilation(File javaSourceFile) throws FileNotFoundException {
        String simpleClassName = FileUtils.extractNameWithoutExtension(javaSourceFile);

        return sourceCodeAfterCompilation(new FileReader(javaSourceFile), simpleClassName);
    }

    /**
     * Returns source code after compilation.
     *
     * @param javaSourceFileReader Java source file content Reader
     * @param simpleClassName      simple class name
     *
     * @return source code after compilation
     */
    public static String sourceCodeAfterCompilation(Reader javaSourceFileReader, String simpleClassName) {
        CompilationUnitTree compilationUnitTree = JavaCompilerUtils.compile(javaSourceFileReader, simpleClassName);

        return compilationUnitTree.toString();
    }
}
